==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QInputAspect.java <==
package io.qt.qt3d.input;


/**
 * <p>Responsible for creating physical devices and handling associated jobs</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qinputaspect.html">Qt3DInput::QInputAspect</a></p>
 */
public class QInputAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QInputAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputaspect.html#QInputAspect">Qt3DInput::QInputAspect::QInputAspect(QObject*)</a></p>
     */
    public QInputAspect(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputAspect instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputaspect.html#availablePhysicalDevices">Qt3DInput::QInputAspect::availablePhysicalDevices()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList availablePhysicalDevices(){
        return availablePhysicalDevices_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList availablePhysicalDevices_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputaspect.html#createPhysicalDevice">Qt3DInput::QInputAspect::createPhysicalDevice(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QAbstractPhysicalDevice createPhysicalDevice(java.lang.String name){
        return createPhysicalDevice_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QAbstractPhysicalDevice createPhysicalDevice_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputAspect instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.4.0-sources.jar: io/qt/qt3d/input/QInputAspect.java <==
package io.qt.qt3d.input;


/**
 * <p>Responsible for creating physical devices and handling associated jobs</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3dinput-qinputaspect.html">Qt3DInput::QInputAspect</a></p>
 */
public class QInputAspect extends io.qt.qt3d.core.QAbstractAspect
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputAspect.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QInputAspect(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputAspect() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputaspect.html#QInputAspect">Qt3DInput::QInputAspect::QInputAspect(QObject*)</a></p>
     */
    public QInputAspect(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputAspect instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputaspect.html#availablePhysicalDevices">Qt3DInput::QInputAspect::availablePhysicalDevices()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QStringList availablePhysicalDevices(){
        return availablePhysicalDevices_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QStringList availablePhysicalDevices_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputaspect.html#createPhysicalDevice">Qt3DInput::QInputAspect::createPhysicalDevice(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QAbstractPhysicalDevice createPhysicalDevice(java.lang.String name){
        return createPhysicalDevice_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QAbstractPhysicalDevice createPhysicalDevice_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputAspect(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputAspect(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputAspect instance, QDeclarativeConstructor constructor);
    
}
